@@ -1,4 +1,3 @@
-
 import os
 import sys
 import logging
@@ -26,7 +25,7 @@ def main():
         sys.exit(1)
 
     if args.url is None:
-        print('Please specify a valid gitlab base url with the -h flag or the \'GITLAB_URL\' environment variable')
+        print('Please specify a valid gitlab base url with the -u flag or the \'GITLAB_URL\' environment variable')
         sys.exit(1)
 
     elif args.dest is None and args.print is False:
@@ -37,9 +36,14 @@ def main():
     includes=split(args.include)
     excludes=split(args.exclude)
 
+    args_print = vars(args).copy()
+    args_print['token'] = '__hidden__'
+    log.debug("running with args [%s]", args_print)
+
     tree = GitlabTree(args.url, args.token, args.method, args.naming, args.archived.api_value, includes,
-                      excludes, args.file, args.concurrency, args.recursive, args.verbose)
-    log.debug("Reading projects tree from gitlab at [%s]", args.url)
+                      excludes, args.file, args.concurrency, args.recursive, args.verbose,
+                      args.include_shared, args.use_fetch, args.hide_token, args.user_projects, 
+                      group_search=args.group_search, git_options=args.git_options)
     tree.load_tree()
 
     if tree.is_empty():
@@ -68,7 +72,7 @@ def config_logging(args):
 
 
 def parse_args(argv=None):
-    example_text = '''examples:
+    example_text = r'''examples:
 
     clone an entire gitlab tree using a url and a token:
     gitlabber -t <personal access token> -u <gitlab url>
@@ -87,6 +91,12 @@ def parse_args(argv=None):
 
     clone projects that start with a case insensitive 'w' using a regular expression:
     gitlabber -i '/{[w].*}' .
+    
+    clone a user's personal projects to username-personal-projects
+    gitlabber -U .
+    
+    perform a shallow clone of the git repositories
+    gitlabber -o "\-\-depth=1," .
     '''
 
     parser = ArgumentParser(
@@ -105,6 +115,12 @@ def parse_args(argv=None):
         metavar=('token'),
         default=os.environ.get('GITLAB_TOKEN'),
         help='gitlab personal access token https://docs.gitlab.com/ee/user/profile/personal_access_tokens.html')
+    parser.add_argument(
+        '-T',
+        '--hide-token',
+        action='store_true',
+        default=False,
+        help='use an inline URL token (avoids storing the gitlab personal access token in the .git/config)')
     parser.add_argument(
         '-u',
         '--url',
@@ -177,16 +193,47 @@ def parse_args(argv=None):
         action='store_true',
         default=False,
         help='clone/pull git submodules recursively')
+    parser.add_argument(
+        '-F',
+        '--use-fetch',
+        action='store_true',
+        default=False,
+        help='clone/fetch git repository (mirrored repositories)')
+    parser.add_argument(
+        '-d',
+        '--dont-checkout',
+        action='store_true',
+        default=False,
+        help="don't checkout pulled git repository")    
+    parser.add_argument(
+        '-s',
+        '--include-shared',
+        action='store_true',
+        default=True,
+        help='include shared projects in the results')
+    parser.add_argument(
+        '-g',
+        '--group-search',
+        metavar=('term'),
+        help='only include groups matching the search term, filtering done at the API level (useful for large projects, see: https://docs.gitlab.com/ee/api/groups.html#search-for-group works with partial names of path or name)')
+    parser.add_argument(
+        '-U',
+        '--user-projects',
+        action='store_true',
+        default=False,
+        help='fetch only user personal projects (skips the group tree altogether, group related parameters are ignored). Clones personal projects to \'{gitlab-username}-personal-projects\'')
+    parser.add_argument(
+        '-o',
+        '--git-options',
+        nargs=1,
+        metavar=('options'),
+        help='provide additional options as csv for the git command (e.g., --depth=1). See: clone/multi_options https://gitpython.readthedocs.io/en/stable/reference.html#')
     parser.add_argument(
         '--version',
         action='store_true',
         help='print the version')
 
-    args = parser.parse_args(argv)
-    args_print = vars(args).copy()
-    args_print['token'] = 'xxxxx'
-    log.debug("running with args [%s]", args_print)
-    return args
+    return parser.parse_args(argv)
 
 def validate_path(value):
     if value.endswith('/'):
